@@ -13,11 +13,11 @@
 
 #include "kgpgtextorfiletransaction.h"
 
+#include "gpgproc.h"
+
 #include <KIO/NetAccess>
 #include <KLocale>
 
-#include "gpgproc.h"
-
 KGpgTextOrFileTransaction::KGpgTextOrFileTransaction(QObject *parent, const QString &text, const bool allowChaining)
 	: KGpgTransaction(parent, allowChaining),
 	m_text(text)
@@ -118,8 +118,9 @@ KGpgTextOrFileTransaction::nextLine(const QString &line)
 void
 KGpgTextOrFileTransaction::finish()
 {
-	if (getProcess()->exitCode() != 0)
+	if (getProcess()->exitCode() != 0) {
 		setSuccess(TS_MSG_SEQUENCE);
+	}
 }
 
 const QStringList &
@@ -144,3 +145,5 @@ KGpgTextOrFileTransaction::getInputFiles() const
 {
 	return m_inpfiles;
 }
+
+#include "kgpgtextorfiletransaction.moc"
